@@ -203,7 +203,8 @@ iir_young_hor_blur (GeglBuffer          *src,
                     const gdouble       *b,
                     gdouble            (*m)[3],
                     GeglAbyssPolicy      policy,
-                    const Babl          *format)
+                    const Babl          *format,
+                    gint                 level)
 {
   GeglRectangle  cur_row = *rect;
   const gint     nc = babl_format_get_n_components (format);
@@ -217,12 +218,12 @@ iir_young_hor_blur (GeglBuffer          *src,
     {
       cur_row.y = rect->y + v;
 
-      gegl_buffer_get (src, &cur_row, 1.0, format, &row[3 * nc],
+      gegl_buffer_get (src, &cur_row, 1.0/(1<<level), format, &row[3 * nc],
                        GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
 
       iir_young_blur_1D (row, tmp, b, m, rect->width, nc, policy);
 
-      gegl_buffer_set (dst, &cur_row, 0, format, &row[3 * nc],
+      gegl_buffer_set (dst, &cur_row, level, format, &row[3 * nc],
                        GEGL_AUTO_ROWSTRIDE);
     }
 
@@ -237,7 +238,8 @@ iir_young_ver_blur (GeglBuffer          *src,
                     const gdouble       *b,
                     gdouble            (*m)[3],
                     GeglAbyssPolicy      policy,
-                    const Babl          *format)
+                    const Babl          *format,
+                    gint                 level)
 {
   GeglRectangle  cur_col = *rect;
   const gint     nc = babl_format_get_n_components (format);
@@ -251,12 +253,12 @@ iir_young_ver_blur (GeglBuffer          *src,
     {
       cur_col.x = rect->x + i;
 
-      gegl_buffer_get (src, &cur_col, 1.0, format, &col[3 * nc],
+      gegl_buffer_get (src, &cur_col, 1.0/(1<<level), format, &col[3 * nc],
                        GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
 
       iir_young_blur_1D (col, tmp, b, m, rect->height, nc, policy);
 
-      gegl_buffer_set (dst, &cur_col, 0, format, &col[3 * nc],
+      gegl_buffer_set (dst, &cur_col, level, format, &col[3 * nc],
                        GEGL_AUTO_ROWSTRIDE);
     }
 
@@ -304,7 +306,8 @@ fir_hor_blur (GeglBuffer          *src,
               gfloat              *cmatrix,
               gint                 clen,
               GeglAbyssPolicy      policy,
-              const Babl          *format)
+              const Babl          *format,
+              gint                 level)
 {
   GeglRectangle  cur_row = *rect;
   GeglRectangle  in_row;
@@ -326,11 +329,11 @@ fir_hor_blur (GeglBuffer          *src,
     {
       cur_row.y = in_row.y = rect->y + v;
 
-      gegl_buffer_get (src, &in_row, 1.0, format, row, GEGL_AUTO_ROWSTRIDE, policy);
+      gegl_buffer_get (src, &in_row, 1.0/(1<<level), format, row, GEGL_AUTO_ROWSTRIDE, policy);
 
       fir_blur_1D (row, out, cmatrix, clen, rect->width, nc);
 
-      gegl_buffer_set (dst, &cur_row, 0, format, out, GEGL_AUTO_ROWSTRIDE);
+      gegl_buffer_set (dst, &cur_row, level, format, out, GEGL_AUTO_ROWSTRIDE);
     }
 
   gegl_free (out);
@@ -344,7 +347,8 @@ fir_ver_blur (GeglBuffer          *src,
               gfloat              *cmatrix,
               gint                 clen,
               GeglAbyssPolicy      policy,
-              const Babl          *format)
+              const Babl          *format,
+              gint                 level)
 {
   GeglRectangle  cur_col = *rect;
   GeglRectangle  in_col;
@@ -366,11 +370,11 @@ fir_ver_blur (GeglBuffer          *src,
     {
       cur_col.x = in_col.x = rect->x + v;
 
-      gegl_buffer_get (src, &in_col, 1.0, format, col, GEGL_AUTO_ROWSTRIDE, policy);
+      gegl_buffer_get (src, &in_col, 1.0/(1<<level), format, col, GEGL_AUTO_ROWSTRIDE, policy);
 
       fir_blur_1D (col, out, cmatrix, clen, rect->height, nc);
 
-      gegl_buffer_set (dst, &cur_col, 0, format, out, GEGL_AUTO_ROWSTRIDE);
+      gegl_buffer_set (dst, &cur_col, level, format, out, GEGL_AUTO_ROWSTRIDE);
     }
 
   gegl_free (out);
@@ -584,6 +588,7 @@ static GeglGblur1dFilter
 filter_disambiguation (GeglGblur1dFilter filter,
                        gfloat            std_dev)
 {
+  return GEGL_GBLUR_1D_IIR;
   if (filter == GEGL_GBLUR_1D_AUTO)
     {
       /* Threshold 1.0 is arbitrary */
@@ -790,31 +795,45 @@ gegl_gblur_1d_process (GeglOperation       *operation,
                        const GeglRectangle *result,
                        gint                 level)
 {
-  GeglProperties *o      = GEGL_PROPERTIES (operation);
-  const Babl *format = gegl_operation_get_format (operation, "output");
+  GeglProperties *o       = GEGL_PROPERTIES (operation);
+  const Babl     *format  = gegl_operation_get_format (operation, "output");
+  gfloat          std_dev = o->std_dev;
 
   GeglGblur1dFilter filter;
   GeglAbyssPolicy   abyss_policy = to_gegl_policy (o->abyss_policy);
 
-  filter = filter_disambiguation (o->filter, o->std_dev);
+  GeglRectangle rect2;
+  //level = 0; // mipmap rendering doesn't work yet, unsure if it is
+             // the code in the op or in GeglBuffer
+  if (level)
+  {
+    rect2 = *result;
+    rect2.x      = result->x >> level;
+    rect2.y      = result->y >> level;
+    rect2.width  = result->width >> level;
+    rect2.height = result->height >> level;
+   // result = &rect2;
+    std_dev = std_dev * (1.0/(1<<level));
+  }
+  filter = filter_disambiguation (o->filter, std_dev);
 
   if (filter == GEGL_GBLUR_1D_IIR)
     {
       gdouble b[4], m[3][3];
 
-      iir_young_find_constants (o->std_dev, b, m);
+      iir_young_find_constants (std_dev, b, m);
 
       if (o->orientation == GEGL_ORIENTATION_HORIZONTAL)
-        iir_young_hor_blur (input, result, output, b, m, abyss_policy, format);
+        iir_young_hor_blur (input, result, output, b, m, abyss_policy, format, level);
       else
-        iir_young_ver_blur (input, result, output, b, m, abyss_policy, format);
+        iir_young_ver_blur (input, result, output, b, m, abyss_policy, format, level);
     }
   else
     {
       gfloat *cmatrix;
       gint    clen;
 
-      clen = fir_gen_convolve_matrix (o->std_dev, &cmatrix);
+      clen = fir_gen_convolve_matrix (std_dev, &cmatrix);
 
       /* FIXME: implement others format cases */
       if (gegl_operation_use_opencl (operation) &&
@@ -827,9 +846,9 @@ gegl_gblur_1d_process (GeglOperation       *operation,
         }
 
       if (o->orientation == GEGL_ORIENTATION_HORIZONTAL)
-        fir_hor_blur (input, result, output, cmatrix, clen, abyss_policy, format);
+        fir_hor_blur (input, result, output, cmatrix, clen, abyss_policy, format, level);
       else
-        fir_ver_blur (input, result, output, cmatrix, clen, abyss_policy, format);
+        fir_ver_blur (input, result, output, cmatrix, clen, abyss_policy, format, level);
 
       gegl_free (cmatrix);
     }
