@@ -204,7 +204,8 @@ static const char* op_c_source =
 "                    const gdouble       *b,                                   \n"
 "                    gdouble            (*m)[3],                               \n"
 "                    GeglAbyssPolicy      policy,                              \n"
-"                    const Babl          *format)                              \n"
+"                    const Babl          *format,                              \n"
+"                    gint                 level)                               \n"
 "{                                                                             \n"
 "  GeglRectangle  cur_row = *rect;                                             \n"
 "  const gint     nc = babl_format_get_n_components (format);                  \n"
@@ -218,12 +219,12 @@ static const char* op_c_source =
 "    {                                                                         \n"
 "      cur_row.y = rect->y + v;                                                \n"
 "                                                                              \n"
-"      gegl_buffer_get (src, &cur_row, 1.0, format, &row[3 * nc],              \n"
+"      gegl_buffer_get (src, &cur_row, 1.0/(1<<level), format, &row[3 * nc],   \n"
 "                       GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);                 \n"
 "                                                                              \n"
 "      iir_young_blur_1D (row, tmp, b, m, rect->width, nc, policy);            \n"
 "                                                                              \n"
-"      gegl_buffer_set (dst, &cur_row, 0, format, &row[3 * nc],                \n"
+"      gegl_buffer_set (dst, &cur_row, level, format, &row[3 * nc],            \n"
 "                       GEGL_AUTO_ROWSTRIDE);                                  \n"
 "    }                                                                         \n"
 "                                                                              \n"
@@ -238,7 +239,8 @@ static const char* op_c_source =
 "                    const gdouble       *b,                                   \n"
 "                    gdouble            (*m)[3],                               \n"
 "                    GeglAbyssPolicy      policy,                              \n"
-"                    const Babl          *format)                              \n"
+"                    const Babl          *format,                              \n"
+"                    gint                 level)                               \n"
 "{                                                                             \n"
 "  GeglRectangle  cur_col = *rect;                                             \n"
 "  const gint     nc = babl_format_get_n_components (format);                  \n"
@@ -252,12 +254,12 @@ static const char* op_c_source =
 "    {                                                                         \n"
 "      cur_col.x = rect->x + i;                                                \n"
 "                                                                              \n"
-"      gegl_buffer_get (src, &cur_col, 1.0, format, &col[3 * nc],              \n"
+"      gegl_buffer_get (src, &cur_col, 1.0/(1<<level), format, &col[3 * nc],   \n"
 "                       GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);                 \n"
 "                                                                              \n"
 "      iir_young_blur_1D (col, tmp, b, m, rect->height, nc, policy);           \n"
 "                                                                              \n"
-"      gegl_buffer_set (dst, &cur_col, 0, format, &col[3 * nc],                \n"
+"      gegl_buffer_set (dst, &cur_col, level, format, &col[3 * nc],            \n"
 "                       GEGL_AUTO_ROWSTRIDE);                                  \n"
 "    }                                                                         \n"
 "                                                                              \n"
@@ -305,7 +307,8 @@ static const char* op_c_source =
 "              gfloat              *cmatrix,                                   \n"
 "              gint                 clen,                                      \n"
 "              GeglAbyssPolicy      policy,                                    \n"
-"              const Babl          *format)                                    \n"
+"              const Babl          *format,                                    \n"
+"              gint                 level)                                     \n"
 "{                                                                             \n"
 "  GeglRectangle  cur_row = *rect;                                             \n"
 "  GeglRectangle  in_row;                                                      \n"
@@ -327,11 +330,11 @@ static const char* op_c_source =
 "    {                                                                         \n"
 "      cur_row.y = in_row.y = rect->y + v;                                     \n"
 "                                                                              \n"
-"      gegl_buffer_get (src, &in_row, 1.0, format, row, GEGL_AUTO_ROWSTRIDE, policy);\n"
+"      gegl_buffer_get (src, &in_row, 1.0/(1<<level), format, row, GEGL_AUTO_ROWSTRIDE, policy);\n"
 "                                                                              \n"
 "      fir_blur_1D (row, out, cmatrix, clen, rect->width, nc);                 \n"
 "                                                                              \n"
-"      gegl_buffer_set (dst, &cur_row, 0, format, out, GEGL_AUTO_ROWSTRIDE);   \n"
+"      gegl_buffer_set (dst, &cur_row, level, format, out, GEGL_AUTO_ROWSTRIDE);\n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  gegl_free (out);                                                            \n"
@@ -345,7 +348,8 @@ static const char* op_c_source =
 "              gfloat              *cmatrix,                                   \n"
 "              gint                 clen,                                      \n"
 "              GeglAbyssPolicy      policy,                                    \n"
-"              const Babl          *format)                                    \n"
+"              const Babl          *format,                                    \n"
+"              gint                 level)                                     \n"
 "{                                                                             \n"
 "  GeglRectangle  cur_col = *rect;                                             \n"
 "  GeglRectangle  in_col;                                                      \n"
@@ -367,11 +371,11 @@ static const char* op_c_source =
 "    {                                                                         \n"
 "      cur_col.x = in_col.x = rect->x + v;                                     \n"
 "                                                                              \n"
-"      gegl_buffer_get (src, &in_col, 1.0, format, col, GEGL_AUTO_ROWSTRIDE, policy);\n"
+"      gegl_buffer_get (src, &in_col, 1.0/(1<<level), format, col, GEGL_AUTO_ROWSTRIDE, policy);\n"
 "                                                                              \n"
 "      fir_blur_1D (col, out, cmatrix, clen, rect->height, nc);                \n"
 "                                                                              \n"
-"      gegl_buffer_set (dst, &cur_col, 0, format, out, GEGL_AUTO_ROWSTRIDE);   \n"
+"      gegl_buffer_set (dst, &cur_col, level, format, out, GEGL_AUTO_ROWSTRIDE);\n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  gegl_free (out);                                                            \n"
@@ -585,6 +589,7 @@ static const char* op_c_source =
 "filter_disambiguation (GeglGblur1dFilter filter,                              \n"
 "                       gfloat            std_dev)                             \n"
 "{                                                                             \n"
+"  return GEGL_GBLUR_1D_IIR;                                                   \n"
 "  if (filter == GEGL_GBLUR_1D_AUTO)                                           \n"
 "    {                                                                         \n"
 "      /* Threshold 1.0 is arbitrary */                                        \n"
@@ -791,31 +796,45 @@ static const char* op_c_source =
 "                       const GeglRectangle *result,                           \n"
 "                       gint                 level)                            \n"
 "{                                                                             \n"
-"  GeglProperties *o      = GEGL_PROPERTIES (operation);                       \n"
-"  const Babl *format = gegl_operation_get_format (operation, \"output\");     \n"
+"  GeglProperties *o       = GEGL_PROPERTIES (operation);                      \n"
+"  const Babl     *format  = gegl_operation_get_format (operation, \"output\");\n"
+"  gfloat          std_dev = o->std_dev;                                       \n"
 "                                                                              \n"
 "  GeglGblur1dFilter filter;                                                   \n"
 "  GeglAbyssPolicy   abyss_policy = to_gegl_policy (o->abyss_policy);          \n"
 "                                                                              \n"
-"  filter = filter_disambiguation (o->filter, o->std_dev);                     \n"
+"  GeglRectangle rect2;                                                        \n"
+"  //level = 0; // mipmap rendering doesn't work yet, unsure if it is          \n"
+"             // the code in the op or in GeglBuffer                           \n"
+"  if (level)                                                                  \n"
+"  {                                                                           \n"
+"    rect2 = *result;                                                          \n"
+"    rect2.x      = result->x >> level;                                        \n"
+"    rect2.y      = result->y >> level;                                        \n"
+"    rect2.width  = result->width >> level;                                    \n"
+"    rect2.height = result->height >> level;                                   \n"
+"   // result = &rect2;                                                        \n"
+"    std_dev = std_dev * (1.0/(1<<level));                                     \n"
+"  }                                                                           \n"
+"  filter = filter_disambiguation (o->filter, std_dev);                        \n"
 "                                                                              \n"
 "  if (filter == GEGL_GBLUR_1D_IIR)                                            \n"
 "    {                                                                         \n"
 "      gdouble b[4], m[3][3];                                                  \n"
 "                                                                              \n"
-"      iir_young_find_constants (o->std_dev, b, m);                            \n"
+"      iir_young_find_constants (std_dev, b, m);                               \n"
 "                                                                              \n"
 "      if (o->orientation == GEGL_ORIENTATION_HORIZONTAL)                      \n"
-"        iir_young_hor_blur (input, result, output, b, m, abyss_policy, format);\n"
+"        iir_young_hor_blur (input, result, output, b, m, abyss_policy, format, level);\n"
 "      else                                                                    \n"
-"        iir_young_ver_blur (input, result, output, b, m, abyss_policy, format);\n"
+"        iir_young_ver_blur (input, result, output, b, m, abyss_policy, format, level);\n"
 "    }                                                                         \n"
 "  else                                                                        \n"
 "    {                                                                         \n"
 "      gfloat *cmatrix;                                                        \n"
 "      gint    clen;                                                           \n"
 "                                                                              \n"
-"      clen = fir_gen_convolve_matrix (o->std_dev, &cmatrix);                  \n"
+"      clen = fir_gen_convolve_matrix (std_dev, &cmatrix);                     \n"
 "                                                                              \n"
 "      /* FIXME: implement others format cases */                              \n"
 "      if (gegl_operation_use_opencl (operation) &&                            \n"
@@ -828,9 +847,9 @@ static const char* op_c_source =
 "        }                                                                     \n"
 "                                                                              \n"
 "      if (o->orientation == GEGL_ORIENTATION_HORIZONTAL)                      \n"
-"        fir_hor_blur (input, result, output, cmatrix, clen, abyss_policy, format);\n"
+"        fir_hor_blur (input, result, output, cmatrix, clen, abyss_policy, format, level);\n"
 "      else                                                                    \n"
-"        fir_ver_blur (input, result, output, cmatrix, clen, abyss_policy, format);\n"
+"        fir_ver_blur (input, result, output, cmatrix, clen, abyss_policy, format, level);\n"
 "                                                                              \n"
 "      gegl_free (cmatrix);                                                    \n"
 "    }                                                                         \n"
