@@ -55,7 +55,7 @@ static const char* op_c_source =
 "    description (_(\"Adjust brightness in corners\"))                         \n"
 "    value_range (-100.0, 100.0)                                               \n"
 "                                                                              \n"
-"property_color  (background, _(\"Background color\"), \"white\")              \n"
+"property_color  (background, _(\"Background color\"), \"none\")               \n"
 "                                                                              \n"
 "#else                                                                         \n"
 "                                                                              \n"
@@ -269,8 +269,8 @@ static const char* op_c_source =
 "}                                                                             \n"
 "                                                                              \n"
 "/*                                                                            \n"
-" * Catmull-Rom cubic interpolation                                            \n"
-" *                                                                            \n"
+" * Catmull-Rom cubic interpolation XXX: FIXME: use gegl resampler instead of  \n"
+" *                                             reimplementing cubic sampler here\n"
 " * equally spaced points p0, p1, p2, p3                                       \n"
 " * interpolate 0 <= u < 1 between p1 and p2                                   \n"
 " *                                                                            \n"
@@ -423,7 +423,7 @@ static const char* op_c_source =
 "  src_buf = g_new0 (gfloat, SQR (MAX_WH) * 4);                                \n"
 "  dst_buf = g_new0 (gfloat, SQR (CHUNK_SIZE) * 4);                            \n"
 "                                                                              \n"
-"  gegl_color_get_pixel (o->background, babl_format (\"RGBA float\"), background);\n"
+"  gegl_color_get_pixel (o->background, babl_format (\"RaGaBaA float\"), background);\n"
 "                                                                              \n"
 "  for (j = 0; (j-1) * CHUNK_SIZE < result->height; j++)                       \n"
 "    for (i = 0; (i-1) * CHUNK_SIZE < result->width; i++)                      \n"
@@ -445,7 +445,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "        clamp_area (&area, lens.centre_x, lens.centre_y);                     \n"
 "                                                                              \n"
-"        gegl_buffer_get (input, &area, 1.0, babl_format (\"RGBA float\"), src_buf,\n"
+"        gegl_buffer_get (input, &area, 1.0, babl_format (\"RaGaBaA float\"), src_buf,\n"
 "                         GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_CLAMP);              \n"
 "                                                                              \n"
 "        for (y = chunked_result.y; y < chunked_result.y + chunked_result.height; y++)\n"
@@ -455,7 +455,7 @@ static const char* op_c_source =
 "                                 &lens, x, y, input, background, level);      \n"
 "            }                                                                 \n"
 "                                                                              \n"
-"        gegl_buffer_set (output, &chunked_result, 0, babl_format (\"RGBA float\"),\n"
+"        gegl_buffer_set (output, &chunked_result, 0, babl_format (\"RaGaBaA float\"),\n"
 "                         dst_buf, GEGL_AUTO_ROWSTRIDE);                       \n"
 "      }                                                                       \n"
 "                                                                              \n"
