@@ -615,7 +615,7 @@ static const char* op_c_source =
 "    {                                                                         \n"
 "      /* allocate memory for maze and set to zero */                          \n"
 "                                                                              \n"
-"      maz = (guchar *) calloc (sizeof(guchar), mw * mh);                      \n"
+"      maz = (guchar *) g_new0 (guchar, mw * mh);                              \n"
 "                                                                              \n"
 "      gr = g_rand_new ();                                                     \n"
 "                                                                              \n"
@@ -711,7 +711,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "      g_rand_free (gr);                                                       \n"
 "                                                                              \n"
-"      free (maz);                                                             \n"
+"      g_free (maz);                                                           \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  return TRUE;                                                                \n"
