@@ -3,7 +3,6 @@
 void gegl_op_alien_map_register_type(GTypeModule *module);
 void gegl_op_antialias_register_type(GTypeModule *module);
 void gegl_op_apply_lens_register_type(GTypeModule *module);
-void gegl_op_bilateral_filter_fast_register_type(GTypeModule *module);
 void gegl_op_bilateral_filter_register_type(GTypeModule *module);
 void gegl_op_box_blur_register_type(GTypeModule *module);
 void gegl_op_brightness_contrast_register_type(GTypeModule *module);
@@ -16,11 +15,13 @@ void gegl_op_channel_mixer_register_type(GTypeModule *module);
 void gegl_op_checkerboard_register_type(GTypeModule *module);
 void gegl_op_color_enhance_register_type(GTypeModule *module);
 void gegl_op_color_exchange_register_type(GTypeModule *module);
-void gegl_op_color_reduction_register_type(GTypeModule *module);
+void gegl_op_dither_register_type(GTypeModule *module);
 void gegl_op_color_rotate_register_type(GTypeModule *module);
 void gegl_op_color_temperature_register_type(GTypeModule *module);
 void gegl_op_color_to_alpha_register_type(GTypeModule *module);
+void gegl_op_color_warp_register_type(GTypeModule *module);
 void gegl_op_color_register_type(GTypeModule *module);
+void gegl_op_component_extract_register_type(GTypeModule *module);
 void gegl_op_contrast_curve_register_type(GTypeModule *module);
 void gegl_op_convolution_matrix_register_type(GTypeModule *module);
 void gegl_op_copy_buffer_register_type(GTypeModule *module);
@@ -34,6 +35,7 @@ void gegl_op_distance_transform_register_type(GTypeModule *module);
 void gegl_op_dropshadow_register_type(GTypeModule *module);
 void gegl_op_edge_register_type(GTypeModule *module);
 void gegl_op_edge_laplace_register_type(GTypeModule *module);
+void gegl_op_edge_neon_register_type(GTypeModule *module);
 void gegl_op_edge_sobel_register_type(GTypeModule *module);
 void gegl_op_emboss_register_type(GTypeModule *module);
 void gegl_op_engrave_register_type(GTypeModule *module);
@@ -43,7 +45,6 @@ void gegl_op_fattal02_register_type(GTypeModule *module);
 void gegl_op_fractal_explorer_register_type(GTypeModule *module);
 void gegl_op_fractal_trace_register_type(GTypeModule *module);
 void gegl_op_gaussian_blur_register_type(GTypeModule *module);
-void gegl_op_gaussian_blur_iir_register_type(GTypeModule *module);
 void gegl_op_gaussian_blur_selective_register_type(GTypeModule *module);
 void gegl_op_gblur_1d_register_type(GTypeModule *module);
 void gegl_op_gegl_buffer_load_op_register_type(GTypeModule *module);
@@ -54,6 +55,7 @@ void gegl_op_grid_register_type(GTypeModule *module);
 void gegl_op_high_pass_register_type(GTypeModule *module);
 void gegl_op_illusion_register_type(GTypeModule *module);
 void gegl_op_image_compare_register_type(GTypeModule *module);
+void gegl_op_image_gradient_register_type(GTypeModule *module);
 void gegl_op_introspect_register_type(GTypeModule *module);
 void gegl_op_invert_gamma_register_type(GTypeModule *module);
 void gegl_op_invert_linear_register_type(GTypeModule *module);
@@ -109,6 +111,7 @@ void gegl_op_save_register_type(GTypeModule *module);
 void gegl_op_sepia_register_type(GTypeModule *module);
 void gegl_op_shift_register_type(GTypeModule *module);
 void gegl_op_sinus_register_type(GTypeModule *module);
+void gegl_op_slic_register_type(GTypeModule *module);
 void gegl_op_snn_mean_register_type(GTypeModule *module);
 void gegl_op_softglow_register_type(GTypeModule *module);
 void gegl_op_stress_register_type(GTypeModule *module);
@@ -131,7 +134,10 @@ void gegl_op_value_propagate_register_type(GTypeModule *module);
 void gegl_op_video_degradation_register_type(GTypeModule *module);
 void gegl_op_vignette_register_type(GTypeModule *module);
 void gegl_op_warp_register_type(GTypeModule *module);
+void gegl_op_waterpixels_register_type(GTypeModule *module);
+void gegl_op_watershed_transform_register_type(GTypeModule *module);
 void gegl_op_waves_register_type(GTypeModule *module);
+void gegl_op_wavelet_blur_register_type(GTypeModule *module);
 void gegl_op_weighted_blend_register_type(GTypeModule *module);
 void gegl_op_whirl_pinch_register_type(GTypeModule *module);
 void gegl_op_wind_register_type(GTypeModule *module);
@@ -155,7 +161,6 @@ gegl_module_register (GTypeModule *module)
   gegl_op_alien_map_register_type(module);
   gegl_op_antialias_register_type(module);
   gegl_op_apply_lens_register_type(module);
-  gegl_op_bilateral_filter_fast_register_type(module);
   gegl_op_bilateral_filter_register_type(module);
   gegl_op_box_blur_register_type(module);
   gegl_op_brightness_contrast_register_type(module);
@@ -168,11 +173,13 @@ gegl_module_register (GTypeModule *module)
   gegl_op_checkerboard_register_type(module);
   gegl_op_color_enhance_register_type(module);
   gegl_op_color_exchange_register_type(module);
-  gegl_op_color_reduction_register_type(module);
+  gegl_op_dither_register_type(module);
   gegl_op_color_rotate_register_type(module);
   gegl_op_color_temperature_register_type(module);
   gegl_op_color_to_alpha_register_type(module);
+  gegl_op_color_warp_register_type(module);
   gegl_op_color_register_type(module);
+  gegl_op_component_extract_register_type(module);
   gegl_op_contrast_curve_register_type(module);
   gegl_op_convolution_matrix_register_type(module);
   gegl_op_copy_buffer_register_type(module);
@@ -186,6 +193,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_dropshadow_register_type(module);
   gegl_op_edge_register_type(module);
   gegl_op_edge_laplace_register_type(module);
+  gegl_op_edge_neon_register_type(module);
   gegl_op_edge_sobel_register_type(module);
   gegl_op_emboss_register_type(module);
   gegl_op_engrave_register_type(module);
@@ -195,7 +203,6 @@ gegl_module_register (GTypeModule *module)
   gegl_op_fractal_explorer_register_type(module);
   gegl_op_fractal_trace_register_type(module);
   gegl_op_gaussian_blur_register_type(module);
-  gegl_op_gaussian_blur_iir_register_type(module);
   gegl_op_gaussian_blur_selective_register_type(module);
   gegl_op_gblur_1d_register_type(module);
   gegl_op_gegl_buffer_load_op_register_type(module);
@@ -206,6 +213,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_high_pass_register_type(module);
   gegl_op_illusion_register_type(module);
   gegl_op_image_compare_register_type(module);
+  gegl_op_image_gradient_register_type(module);
   gegl_op_introspect_register_type(module);
   gegl_op_invert_gamma_register_type(module);
   gegl_op_invert_linear_register_type(module);
@@ -261,6 +269,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_sepia_register_type(module);
   gegl_op_shift_register_type(module);
   gegl_op_sinus_register_type(module);
+  gegl_op_slic_register_type(module);
   gegl_op_snn_mean_register_type(module);
   gegl_op_softglow_register_type(module);
   gegl_op_stress_register_type(module);
@@ -283,7 +292,10 @@ gegl_module_register (GTypeModule *module)
   gegl_op_video_degradation_register_type(module);
   gegl_op_vignette_register_type(module);
   gegl_op_warp_register_type(module);
+  gegl_op_waterpixels_register_type(module);
+  gegl_op_watershed_transform_register_type(module);
   gegl_op_waves_register_type(module);
+  gegl_op_wavelet_blur_register_type(module);
   gegl_op_weighted_blend_register_type(module);
   gegl_op_whirl_pinch_register_type(module);
   gegl_op_wind_register_type(module);
