@@ -541,7 +541,7 @@ static const char* op_c_source =
 "    \"reference-composition\", composition,                                   \n"
 "    \"position-dependent\",    \"true\",                                      \n"
 "    \"categories\" ,           \"map\",                                       \n"
-"    \"description\", _(\"Perform a equlinear/gnomonic or little planet/stereographic projection of a equirectangular input image.\"),\n"
+"    \"description\", _(\"Perform an equilinear/gnomonic or little planet/stereographic projection of an equirectangular input image.\"),\n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
 "#endif                                                                        \n"
