@@ -22,8 +22,8 @@ static const char* op_c_source =
 "                                                                              \n"
 "#ifdef GEGL_PROPERTIES                                                        \n"
 "                                                                              \n"
-"property_double (scale, _(\"Scale\"), 1.0)                                    \n"
-"    description(_(\"Scale, strength of effect\"))                             \n"
+"property_double (scale, _(\"Effect strength\"), 1.0)                          \n"
+"    description(_(\"Strength of the sepia effect\"))                          \n"
 "    value_range (0.0, 1.0)                                                    \n"
 "                                                                              \n"
 "property_boolean (srgb, _(\"sRGB\"), TRUE)                                    \n"
@@ -111,7 +111,7 @@ static const char* op_c_source =
 "    \"name\"       , \"gegl:sepia\",                                          \n"
 "    \"title\",       _(\"Sepia\"),                                            \n"
 "    \"categories\" , \"color\",                                               \n"
-"    \"description\", _(\"Converts the input image to sepia\"),                \n"
+"    \"description\", _(\"Apply a sepia tone to the input image\"),            \n"
 "    NULL);                                                                    \n"
 "}                                                                             \n"
 "                                                                              \n"
