@@ -72,7 +72,7 @@ static const char* op_c_source =
 "    GEGL_SINUS_BLEND_SINUSOIDAL)                                              \n"
 "                                                                              \n"
 "property_double (blend_power, _(\"Exponent\"), 0.0)                           \n"
-"    description (_(\"Power used to strech the blend\"))                       \n"
+"    description (_(\"Power used to stretch the blend\"))                      \n"
 "    value_range (-7.5, 7.5)                                                   \n"
 "                                                                              \n"
 "property_int    (width, _(\"Width\"), 1024)                                   \n"
