@@ -147,7 +147,7 @@ static const char* op_c_source =
 "          gfloat  accumulated[4]={0.0f, 0.0f, 0.0f, 0.0f};                    \n"
 "          gint    count=0;                                                    \n"
 "                                                                              \n"
-"          /* iterate through the upper left quater of pixels */               \n"
+"          /* iterate through the upper left quarter of pixels */              \n"
 "          for (v=-radius;v<=0;v++)                                            \n"
 "            for (u=-radius;u<= (pairs==1?radius:0);u++)                       \n"
 "              {                                                               \n"
@@ -336,7 +336,7 @@ static const char* op_c_source =
 "    \"title\",       _(\"Symmetric Nearest Neighbour\"),                      \n"
 "    \"description\",                                                          \n"
 "        _(\"Noise reducing edge preserving blur filter based \"               \n"
-"          \" on Symmetric Nearest Neighbours\"),                              \n"
+"          \"on Symmetric Nearest Neighbours\"),                               \n"
 "        NULL);                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
