@@ -97,6 +97,8 @@ static const char* op_c_source =
 "  result.width  = o->width;                                                   \n"
 "  result.height = o->height;                                                  \n"
 "                                                                              \n"
+"  gegl_rectangle_intersect (&result, &result, in_rect);                       \n"
+"                                                                              \n"
 "  return result;                                                              \n"
 "}                                                                             \n"
 "                                                                              \n"
@@ -105,12 +107,12 @@ static const char* op_c_source =
 "                                     const gchar         *input_pad,          \n"
 "                                     const GeglRectangle *input_region)       \n"
 "{                                                                             \n"
-"  GeglProperties   *o = GEGL_PROPERTIES (operation);                          \n"
-"  GeglRectangle result;                                                       \n"
+"  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
+"  GeglRectangle   result;                                                     \n"
 "                                                                              \n"
-"  result.x = o->x;                                                            \n"
-"  result.y = o->y;                                                            \n"
-"  result.width = o->width;                                                    \n"
+"  result.x      = o->x;                                                       \n"
+"  result.y      = o->y;                                                       \n"
+"  result.width  = o->width;                                                   \n"
 "  result.height = o->height;                                                  \n"
 "                                                                              \n"
 "  gegl_rectangle_intersect (&result, &result, input_region);                  \n"
@@ -123,8 +125,8 @@ static const char* op_c_source =
 "                                   const gchar         *input_pad,            \n"
 "                                   const GeglRectangle *roi)                  \n"
 "{                                                                             \n"
-"  GeglProperties   *o = GEGL_PROPERTIES (operation);                          \n"
-"  GeglRectangle result;                                                       \n"
+"  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
+"  GeglRectangle   result;                                                     \n"
 "                                                                              \n"
 "  result.x      = o->x;                                                       \n"
 "  result.y      = o->y;                                                       \n"
@@ -145,18 +147,25 @@ static const char* op_c_source =
 "  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
 "  GeglBuffer     *input;                                                      \n"
 "  gboolean        success = FALSE;                                            \n"
-"  GeglRectangle   extent;                                                     \n"
-"                                                                              \n"
-"  extent.x      = o->x;                                                       \n"
-"  extent.y      = o->y;                                                       \n"
-"  extent.width  = o->width;                                                   \n"
-"  extent.height = o->height;                                                  \n"
 "                                                                              \n"
 "  input = gegl_operation_context_get_source (context, \"input\");             \n"
 "                                                                              \n"
 "  if (input)                                                                  \n"
 "    {                                                                         \n"
-"      GeglBuffer *output = gegl_buffer_create_sub_buffer (input, &extent);    \n"
+"      GeglRectangle  extent;                                                  \n"
+"      GeglBuffer    *output;                                                  \n"
+"                                                                              \n"
+"      extent = *GEGL_RECTANGLE (o->x, o->y,  o->width, o->height);            \n"
+"                                                                              \n"
+"      /* The output buffer's extent must be a subset of the input buffer's    \n"
+"       * extent; otherwise, if the output buffer is reused for in-place output,\n"
+"       * we might try to write to areas of the buffer that lie outside the    \n"
+"       * input buffer, erroneously discarding the data.                       \n"
+"       */                                                                     \n"
+"      gegl_rectangle_intersect (&extent,                                      \n"
+"                                &extent, gegl_buffer_get_extent (input));     \n"
+"                                                                              \n"
+"      output = gegl_buffer_create_sub_buffer (input, &extent);                \n"
 "                                                                              \n"
 "      if (gegl_object_get_has_forked (G_OBJECT (input)))                      \n"
 "        gegl_object_set_has_forked (G_OBJECT (output));                       \n"
