@@ -36,6 +36,8 @@ static const char* op_c_source =
 "dropshadow a good initial testcase?                                           \n"
 "*/                                                                            \n"
 "                                                                              \n"
+"//#define GEGL_OP_NAME json                                                   \n"
+"                                                                              \n"
 "#include <json-glib/json-glib.h>                                              \n"
 "#include <gegl-plugin.h>                                                      \n"
 "                                                                              \n"
@@ -606,6 +608,14 @@ static const char* op_c_source =
 "gboolean                gegl_module_register (GTypeModule *module);           \n"
 "const GeglModuleInfo  * gegl_module_query    (GTypeModule *module);           \n"
 "                                                                              \n"
+"                                                                              \n"
+"#ifdef GEGL_OP_BUNDLE                                                         \n"
+"                                                                              \n"
+"G_MODULE_EXPORT void                                                          \n"
+"gegl_op_json_register_type (GTypeModule *module)                              \n"
+"{                                                                             \n"
+"#else                                                                         \n"
+"                                                                              \n"
 "G_MODULE_EXPORT const GeglModuleInfo *                                        \n"
 "gegl_module_query (GTypeModule *module)                                       \n"
 "{                                                                             \n"
@@ -615,13 +625,15 @@ static const char* op_c_source =
 "G_MODULE_EXPORT gboolean                                                      \n"
 "gegl_module_register (GTypeModule *module)                                    \n"
 "{                                                                             \n"
+"#endif                                                                        \n"
 "  /* Ensure the module, or shared libs it pulls in is not unloaded            \n"
 "   * This because when GTypes are registered (like for json-glib),            \n"
 "   *  all referenced data must stay in memory until process exit */           \n"
 "  g_module_make_resident (GEGL_MODULE (module)->module);                      \n"
 "                                                                              \n"
 "  json_register_operations (module);                                          \n"
-"                                                                              \n"
+"#ifndef GEGL_OP_BUNDLE                                                        \n"
 "  return TRUE;                                                                \n"
+"#endif                                                                        \n"
 "}                                                                             \n"
 ;
