@@ -66,16 +66,10 @@ static const char* op_c_source =
 "raw_close (GeglProperties *o)                                                 \n"
 "{                                                                             \n"
 "  Private *p = (Private*)o->user_data;                                        \n"
-"  if (p->LibRaw != NULL)                                                      \n"
-"    {                                                                         \n"
-"      if (p->image != NULL)                                                   \n"
-"      {                                                                       \n"
-"        libraw_dcraw_clear_mem (p->image);                                    \n"
-"        p->image = NULL;                                                      \n"
-"      }                                                                       \n"
-"      libraw_close (p->LibRaw);                                               \n"
-"      p->LibRaw = NULL;                                                       \n"
-"    }                                                                         \n"
+"                                                                              \n"
+"  g_clear_pointer (&p->cached_path, g_free);                                  \n"
+"  g_clear_pointer (&p->image, (GDestroyNotify) libraw_dcraw_clear_mem);       \n"
+"  g_clear_pointer (&p->LibRaw, (GDestroyNotify) libraw_close);                \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static void                                                                   \n"
@@ -87,30 +81,40 @@ static const char* op_c_source =
 "                                                                              \n"
 "  if (p == NULL)                                                              \n"
 "    {                                                                         \n"
-"      if ((p = g_new0(Private, 1)) == NULL)                                   \n"
-"        g_warning (\"raw-load: Error creating private structure\");           \n"
+"      p = g_new0(Private, 1);                                                 \n"
+"      o->user_data = (gpointer)p;                                             \n"
 "    }                                                                         \n"
 "                                                                              \n"
-"  if (p->cached_path && !strcmp (p->cached_path, o->path))                    \n"
+"  if (p->cached_path && strcmp (p->cached_path, o->path))                     \n"
 "  {                                                                           \n"
 "     raw_close (o);                                                           \n"
 "  }                                                                           \n"
 "                                                                              \n"
 "  if (p->LibRaw == NULL)                                                      \n"
 "    {                                                                         \n"
-"      o->user_data = (gpointer)p;                                             \n"
-"      p->LibRaw = NULL;                                                       \n"
-"      p->image = NULL;                                                        \n"
+"      g_return_if_fail (p->image == NULL);                                    \n"
 "                                                                              \n"
-"      if ((p->LibRaw = libraw_init(0)) == NULL)                               \n"
+"      if ((p->LibRaw = libraw_init(LIBRAW_OPTIONS_NONE)) == NULL)             \n"
 "        g_warning (\"raw-load: Error Initializing raw library\");             \n"
 "      else                                                                    \n"
 "        {                                                                     \n"
 "          p->LibRaw->params.shot_select = o->image_num;                       \n"
 "                                                                              \n"
-"          p->LibRaw->params.gamm[0] = 1.0;                                    \n"
-"          p->LibRaw->params.gamm[1] = 1.0;                                    \n"
+"          p->LibRaw->params.aber[0] = 1.0;                                    \n"
+"          p->LibRaw->params.aber[2] = 1.0;                                    \n"
+"          p->LibRaw->params.gamm[0] = 1.0 / 2.4;                              \n"
+"          p->LibRaw->params.gamm[1] = 12.92;                                  \n"
+"          p->LibRaw->params.bright = 1.0f;                                    \n"
+"          p->LibRaw->params.half_size = FALSE;                                \n"
+"          p->LibRaw->params.highlight = 0;                                    \n"
+"          p->LibRaw->params.use_auto_wb = TRUE;                               \n"
+"          p->LibRaw->params.use_camera_wb = TRUE;                             \n"
+"          p->LibRaw->params.use_camera_matrix = 1;                            \n"
+"          p->LibRaw->params.output_color = 1;                                 \n"
+"          p->LibRaw->params.user_flip = 0;                                    \n"
 "          p->LibRaw->params.no_auto_bright = 1;                               \n"
+"          p->LibRaw->params.auto_bright_thr = 0.01f;                          \n"
+"          p->LibRaw->params.use_fuji_rotate = -1;                             \n"
 "                                                                              \n"
 "          p->LibRaw->params.output_bps = 16;                                  \n"
 "          p->LibRaw->params.user_qual = o->quality;                           \n"
@@ -141,13 +145,12 @@ static const char* op_c_source =
 "      p = (Private*)o->user_data;                                             \n"
 "    }                                                                         \n"
 "                                                                              \n"
-"  if (p != NULL &&                                                            \n"
-"      p->LibRaw != NULL &&                                                    \n"
+"  if (p->LibRaw != NULL &&                                                    \n"
 "      (p->LibRaw->progress_flags & LIBRAW_PROGRESS_IDENTIFY))                 \n"
 "    {                                                                         \n"
 "      result.width  = p->LibRaw->sizes.width;                                 \n"
 "      result.height = p->LibRaw->sizes.height;                                \n"
-"      gegl_operation_set_format (operation, \"output\", babl_format (\"RGB u16\"));\n"
+"      gegl_operation_set_format (operation, \"output\", babl_format (\"R'G'B' u16\"));\n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  return result;                                                              \n"
@@ -167,8 +170,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  g_assert (p);                                                               \n"
 "                                                                              \n"
-"  if (p != NULL &&                                                            \n"
-"      p->LibRaw != NULL)                                                      \n"
+"  if (p->LibRaw != NULL)                                                      \n"
 "    {                                                                         \n"
 "      if (!(p->LibRaw->progress_flags & LIBRAW_PROGRESS_LOAD_RAW))            \n"
 "        {                                                                     \n"
@@ -192,9 +194,9 @@ static const char* op_c_source =
 "      rect.height = p->image->height;                                         \n"
 "                                                                              \n"
 "      if (p->image->colors == 1)                                              \n"
-"        format = babl_format (\"Y u16\");                                     \n"
+"        format = babl_format (\"Y' u16\");                                    \n"
 "      else // 3 color channels                                                \n"
-"        format = babl_format (\"RGB u16\");                                   \n"
+"        format = babl_format (\"R'G'B' u16\");                                \n"
 "                                                                              \n"
 "      gegl_buffer_set (output, &rect, 0, format, p->image->data, GEGL_AUTO_ROWSTRIDE);\n"
 "      return TRUE;                                                            \n"
@@ -286,7 +288,12 @@ static const char* op_c_source =
 "  gegl_operation_handlers_register_loader (                                   \n"
 "    \".cr2\", \"gegl:raw-load\");                                             \n"
 "                                                                              \n"
-"  done = TRUE;                                                                \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-sony-arw\", \"gegl:raw-load\");                                 \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".arw\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+" done = TRUE;                                                                 \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
