@@ -64,11 +64,8 @@ static const char* op_c_source =
 "                                                                              \n"
 "  if (p != NULL)                                                              \n"
 "    {                                                                         \n"
-"      if (p->handle != NULL)                                                  \n"
-"        g_clear_object (&p->handle);                                          \n"
-"                                                                              \n"
-"      if (p->file != NULL)                                                    \n"
-"        g_clear_object(&p->file);                                             \n"
+"      g_clear_object (&p->handle);                                            \n"
+"      g_clear_object (&p->file);                                              \n"
 "                                                                              \n"
 "      p->width = p->height = 0;                                               \n"
 "      p->format = NULL;                                                       \n"
