@@ -83,12 +83,11 @@ cleanup(GeglOperation *operation)
         TIFFClose(p->tiff);
       else if (p->stream != NULL)
         g_input_stream_close(G_INPUT_STREAM(p->stream), NULL, NULL);
-      if (p->stream != NULL)
-        g_clear_object(&p->stream);
+
+      g_clear_object (&p->stream);
       p->tiff = NULL;
 
-      if (p->file != NULL)
-        g_clear_object(&p->file);
+      g_clear_object (&p->file);
 
       p->width = p->height = 0;
       p->directory = 0;
