@@ -31,6 +31,7 @@ static const char* op_c_source =
 "#else                                                                         \n"
 "                                                                              \n"
 "#define GEGL_OP_AREA_FILTER                                                   \n"
+"#define GEGL_OP_NAME demosaic_bimedian                                        \n"
 "#define GEGL_OP_C_SOURCE demosaic-bimedian.c                                  \n"
 "                                                                              \n"
 "#include \"gegl-op.h\"                                                        \n"
@@ -217,6 +218,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "    \"name\"        , \"gegl:demosaic-bimedian\",                             \n"
+"    \"title\"       , _(\"Demosaic With Bimedian Interpolation\"),            \n"
 "    \"categories\"  , \"blur\",                                               \n"
 "    \"description\" ,                                                         \n"
 "          _(\"Performs a grayscale2color demosaicing of an image, using bimedian interpolation.\"),\n"
