@@ -24,25 +24,17 @@ static const char* op_c_source =
 "#ifdef GEGL_PROPERTIES                                                        \n"
 "                                                                              \n"
 "#define THRESHOLD_SCRIPT \\                                                   \n"
-"\"level = user_value/2\\n\"\\                                                 \n"
-"\"for y=bound_y0, bound_y1 do\\n\"\\                                          \n"
-"\"  for x=bound_x0, bound_x1 do\\n\"\\                                        \n"
-"\"    v = get_value (x,y)\\n\"\\                                              \n"
-"\"    v = v + get_value (1, x,y)\\n\"\\                                       \n"
-"\"    if v>level then\\n\"\\                                                  \n"
-"\"      v=1.0\\n\"\\                                                          \n"
-"\"    else\\n\"\\                                                             \n"
-"\"      v=0.0\\n\"\\                                                          \n"
-"\"    end\\n\"\\                                                              \n"
-"\"    set_value (x,y,v)\\n\"\\                                                \n"
-"\"  end\\n\"\\                                                                \n"
-"\"  progress (y/height)\\n\"\\                                                \n"
-"\"end\"                                                                       \n"
+"\"r,g,b = get_rgb (x,y)\\n\"\\                                                \n"
+"\"set_rgb (x,y,g,g,g)\\n\"\\                                                  \n"
 "                                                                              \n"
 "property_string (script, _(\"Script\"), THRESHOLD_SCRIPT)                     \n"
 "    description(_(\"The lua script containing the implementation of this operation.\"))\n"
 "    ui_meta    (\"multiline\", \"true\")                                      \n"
 "                                                                              \n"
+"property_string (error, _(\"Lua error\"), \"\")                               \n"
+"    description(_(\"parse/compile error, if any\"))                           \n"
+"    ui_meta    (\"error\", \"true\")                                          \n"
+"                                                                              \n"
 "property_file_path (file, _(\"File\"), \"\")                                  \n"
 "    description(_(\"a stored lua script on disk implementing an operation.\"))\n"
 "                                                                              \n"
@@ -53,6 +45,7 @@ static const char* op_c_source =
 "#else                                                                         \n"
 "                                                                              \n"
 "#define GEGL_OP_COMPOSER                                                      \n"
+"#define GEGL_OP_NAME     gluas                                                \n"
 "#define GEGL_OP_C_SOURCE gluas.c                                              \n"
 "                                                                              \n"
 "#include \"gegl-op.h\"                                                        \n"
@@ -178,7 +171,7 @@ static const char* op_c_source =
 "    lua_pushlightuserdata (L, &p);                                            \n"
 "    lua_settable (L, LUA_REGISTRYINDEX);                                      \n"
 "                                                                              \n"
-"    p.in_drawable = drawable;                                                 \n"
+"    p.in_drawable  = drawable;                                                \n"
 "    p.aux_drawable = aux;                                                     \n"
 "    p.out_drawable = result;                                                  \n"
 "                                                                              \n"
@@ -196,16 +189,29 @@ static const char* op_c_source =
 "                                                                              \n"
 "      luaL_loadstring (L, \"os.setlocale ('C', 'numeric')\");                 \n"
 "                                                                              \n"
+"                                                                              \n"
+"      /* insert default loop start/end filling the selection */               \n"
 "      if (file && file[0]!='\\0')                                             \n"
 "        status = luaL_loadfile (L, file);                                     \n"
 "      else if (buffer)                                                        \n"
-"        status = luaL_loadbuffer (L, buffer, strlen (buffer), \"buffer\");    \n"
+"      {                                                                       \n"
+"        GString *str = g_string_new (buffer);                                 \n"
+"                                                                              \n"
+"        if (!strstr (buffer, \"for x\"))                                      \n"
+"        {                                                                     \n"
+"          g_string_prepend (str, \"for y=bound_y0, bound_y1 do\\n for x=bound_x0, bound_x1 do\\n\");\n"
+"          g_string_append (str, \" end \\n progress (y/height)\\n end\\n\");  \n"
+"        }                                                                     \n"
+"        status = luaL_loadbuffer (L, str->str, str->len, \"buffer\");         \n"
+"                                                                              \n"
+"        g_string_free (str, TRUE);                                            \n"
+"      }                                                                       \n"
 "                                                                              \n"
 "      if (status == 0)                                                        \n"
 "        status = lua_pcall (L, 0, LUA_MULTRET, 0);                            \n"
 "                                                                              \n"
 "      if (status != 0)                                                        \n"
-"        g_warning (\"lua error: %s\", lua_tostring (L, -1));                  \n"
+"        gegl_node_set (op->node, \"error\", lua_tostring (L, -1), NULL);      \n"
 "    }                                                                         \n"
 "}                                                                             \n"
 "                                                                              \n"
@@ -920,8 +926,8 @@ static const char* op_c_source =
 "static void                                                                   \n"
 "prepare (GeglOperation *operation)                                            \n"
 "{                                                                             \n"
-"  gegl_operation_set_format (operation, \"input\", babl_format (\"RGBA float\"));\n"
-"  gegl_operation_set_format (operation, \"aux\", babl_format (\"RGBA float\"));\n"
+"  gegl_operation_set_format (operation, \"input\",  babl_format (\"RGBA float\"));\n"
+"  gegl_operation_set_format (operation, \"aux\",    babl_format (\"RGBA float\"));\n"
 "  gegl_operation_set_format (operation, \"output\", babl_format (\"RGBA float\"));\n"
 "}                                                                             \n"
 "                                                                              \n"
