@@ -38,6 +38,7 @@ static const char* op_c_source =
 "#else                                                                         \n"
 "                                                                              \n"
 "#define GEGL_OP_POINT_FILTER                                                  \n"
+"#define GEGL_OP_NAME gradient_map                                             \n"
 "#define GEGL_OP_C_SOURCE gradient-map.c                                       \n"
 "                                                                              \n"
 "#include \"gegl-op.h\"                                                        \n"
@@ -116,10 +117,12 @@ static const char* op_c_source =
 "            rgba_from_gegl_color(&from, colors[from_stop], format);           \n"
 "            rgba_from_gegl_color(&to, colors[to_stop], format);               \n"
 "        }                                                                     \n"
+"        {                                                                     \n"
 "        const float from_pos = (from_stop < 0) ? 0.0 : stops[from_stop];      \n"
 "        const float weight = ((to_stop-from_stop) == 0) ? 1.0 : mapf(pos, from_pos, to_pos, 0.0, 1.0);\n"
 "        const size_t offset = px*channels;                                    \n"
 "        pixel_interpolate_gradient(samples, offset, &from, &to, weight);      \n"
+"        }                                                                     \n"
 "    }                                                                         \n"
 "    return samples;                                                           \n"
 "}                                                                             \n"
@@ -240,6 +243,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "      \"name\",       \"gegl:gradient-map\",                                  \n"
+"      \"title\"      , _(\"Gradient Map\"),                                   \n"
 "      \"categories\", \"color\",                                              \n"
 "      \"description\", _(\"Applies a color gradient.\"),                      \n"
 "      \"reference-composition\", composition,                                 \n"
